@@ -6,13 +6,12 @@ import numpy as np
 from scipy.signal import fftconvolve
 import simdkalman
 
-from .utils.utils_class import LinearRegression
-from .utils.utils_func import (create_windows, sigma_interval, kalman_interval,
-                                confidence_interval, prediction_interval)
-from .utils.utils_func import (_check_noise_dict, _check_knots, _check_weights,
-                                _check_data, _check_data_nan, _check_output)
-from .utils.regression_basis import (polynomial, linear_spline, cubic_spline, natural_cubic_spline,
-                                      gaussian_kernel, binner, lowess)
+from .utils_class import LinearRegression
+from .utils_func import (create_windows, sigma_interval, kalman_interval)
+from .utils_func import (_check_noise_dict, _check_knots, _check_weights,
+                         _check_data, _check_data_nan, _check_output)
+from .regression_basis import (polynomial, linear_spline, cubic_spline, natural_cubic_spline,
+                               gaussian_kernel, binner, lowess)
 
 
 
